@@ -1,6 +1,6 @@
 package Workflow;
 
-# $Id: Workflow.pm 468 2009-03-23 12:27:08Z jonasbn $
+# $Id: Workflow.pm 480 2009-09-18 18:47:52Z jonasbn $
 
 use warnings;
 use strict;
@@ -15,7 +15,7 @@ use English qw( -no_match_vars );
 my @FIELDS = qw( id type description state last_update time_zone );
 __PACKAGE__->mk_accessors(@FIELDS);
 
-$Workflow::VERSION = '1.33_2';
+$Workflow::VERSION = '1.33_4';
 
 use constant NO_CHANGE_VALUE => 'NOCHANGE';
 
@@ -1324,6 +1324,9 @@ Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
 
 The following folks have also helped out:
 
+Danny Sadinoff, patches to give better control of initial state and history 
+records for workflow
+
 Ivan Paponov, for patch implementing action groups, See Changes file, 0.32_7
 
 Robert Stockdale, for patch implementing dynamic names for conditions,
