@@ -1,26 +1,40 @@
 package Workflow::Config;
 
-# $Id: Config.pm 292 2007-06-19 14:48:02Z jonasbn $
+# $Id: Config.pm 479 2009-07-19 19:45:30Z jonasbn $
 
+use warnings;
 use strict;
 use base qw( Class::Factory );
-use Data::Dumper        qw( Dumper );
-use Log::Log4perl       qw( get_logger );
+use Data::Dumper qw( Dumper );
+use Log::Log4perl qw( get_logger );
 use Workflow::Exception qw( configuration_error );
 
-$Workflow::Config::VERSION = '1.12';
+$Workflow::Config::VERSION = '1.13';
 
-my %VALID_TYPES = map { $_ => 1 } qw( action condition persister validator workflow );
+# Map the valid type to the top-level XML tag or data
+# structure to look for.
+my %VALID_TYPES = (
+    action    => 'actions',
+    condition => 'conditions',
+    persister => 'persister',
+    validator => 'validators',
+    workflow  => 'workflow',
+);
 
 sub is_valid_config_type {
     my ( $class, $type ) = @_;
-    return $VALID_TYPES{ $type };
+    return $VALID_TYPES{$type};
 }
 
 sub get_valid_config_types {
     return sort keys %VALID_TYPES;
 }
 
+sub get_config_type_tag {
+    my ( $class, $type ) = @_;
+    return $VALID_TYPES{$type};
+}
+
 # Class method that allows you to pass in any type of items in
 # @items. So you can do:
 #
@@ -36,50 +50,50 @@ sub parse_all_files {
 
     my @configurations = ();
 
-    foreach my $file ( @files ) {
-        next unless ( $file );
-        my ( $file_type ) = $file =~ /\.(\w+)$/;
-        unless ( $parse_types{ $file_type } ) {
+    foreach my $file (@files) {
+        next unless ($file);
+        my ($file_type) = $file =~ /\.(\w+)$/;
+        unless ( $parse_types{$file_type} ) {
             configuration_error
                 "Cannot parse configuration file '$file' of workflow ",
                 "type '$type'. The file has unknown configuration type ",
-                "'$file_type'; known configuration types are: ",
-                "'", join( ', ', keys %parse_types ), "'";
+                "'$file_type'; known configuration types are: ", "'",
+                join( ', ', keys %parse_types ), "'";
         }
-        unless ( $parsers{ $file_type } ) {
-            $parsers{ $file_type } = $class->new( $file_type );
+        unless ( $parsers{$file_type} ) {
+            $parsers{$file_type} = $class->new($file_type);
         }
-        push @configurations, $parsers{ $file_type }->parse( $type, $file );
+        push @configurations, $parsers{$file_type}->parse( $type, $file );
     }
     return @configurations;
 }
 
 sub parse {
     my ( $self, $type, @items ) = @_;
-    my $class = ref( $self ) || $self;
+    my $class = ref($self) || $self;
     configuration_error "Class $class must implement 'parse()'";
 }
 
 sub _check_config_type {
     my ( $class, $type ) = @_;
-    unless ( $class->is_valid_config_type( $type ) ) {
+    unless ( $class->is_valid_config_type($type) ) {
         configuration_error "When parsing a configuration file the ",
-                            "configuration type (first argument) must be ",
-                            "one of: ", join( ', ', $class->get_valid_config_types );
+            "configuration type (first argument) must be ", "one of: ",
+            join ', ', $class->get_valid_config_types;
     }
 }
 
 sub _expand_refs {
-    my ( @items ) = @_;
+    my (@items) = @_;
     my @all = ();
 
-    if (! scalar @items) {
+    if ( !scalar @items ) {
         return @all;
     }
-    
-    foreach my $item ( @items ) {
-        next unless ( $item );
-        push @all, ( ref $item eq 'ARRAY' ) ? @{ $item } : $item;
+
+    foreach my $item (@items) {
+        next unless ($item);
+        push @all, ( ref $item eq 'ARRAY' ) ? @{$item} : $item;
     }
     return @all;
 }
@@ -96,6 +110,10 @@ __END__
 
 Workflow::Config - Parse configuration files for the workflow components
 
+=head1 VERSION
+
+This documentation describes version 1.12 of this package
+
 =head1 SYNOPSIS
 
  # Reference multiple files
@@ -232,6 +250,11 @@ if not. Valid configuration types are: 'action', 'condition',
 
 Returns list of strings representing the valid configuration types.
 
+=head3 get_config_type_tag( $class, $type )
+
+Returns string representing a valid configuration type, looking up the type
+parameter in a lookuptable defined in Workflow::Config class.
+
 =head2 Required Object Methods
 
 =head3 parse( $workflow_config_type, @items )
@@ -273,9 +296,10 @@ workflow pieces:
 =head2 workflow
 
    workflow
-      type        $
-      description $
-      persister   $
+      type          $
+      description   $
+      persister     $
+      initial_state $
       observer    \@
           sub           $
           class         $
@@ -299,10 +323,16 @@ the 'type' and 'description' keys are at the top level
 the 'extra_data' key holds an array of zero or more hashrefs with
 'table', 'field', 'class' and 'context' keys
 
+
+=item *
+
+'initial_state' key holds a string declaring the name of the initial state.
+by default, this value is 'INIITAL'.
+
 =item *
 
 'state' key holds array of one or more 'state' declarations; one of
-them must be 'INITIAL'
+them must be 'INITIAL' (or the value of initial_state, if it's defined)
 
 =item *
 
