@@ -1,6 +1,6 @@
 package Workflow::Factory;
 
-# $Id: Factory.pm 464 2009-03-23 11:58:41Z jonasbn $
+# $Id: Factory.pm 479 2009-07-19 19:45:30Z jonasbn $
 
 use warnings;
 use strict;
@@ -54,9 +54,10 @@ require Workflow::Persister;
 require Workflow::State;
 require Workflow::Validator;
 
-my $INITIAL_STATE = 'INITIAL';
+my $DEFAULT_INITIAL_STATE = 'INITIAL';
 
-my @FIELDS = qw(config_callback);
+
+my @FIELDS = qw();
 __PACKAGE__->mk_accessors(@FIELDS);
 
 sub new {
@@ -332,7 +333,8 @@ sub create_workflow {
     unless ($wf_config) {
         workflow_error "No workflow of type '$wf_type' available";
     }
-    my $wf = Workflow->new( undef, $INITIAL_STATE, $wf_config,
+    
+    my $wf = Workflow->new( undef, $wf_config->{initial_state}|| $DEFAULT_INITIAL_STATE, $wf_config,
         $self->{_workflow_state}{$wf_type} );
     $wf->context( Workflow::Context->new );
     $wf->last_update( DateTime->now( time_zone => $wf->time_zone() ) );
@@ -348,9 +350,9 @@ sub create_workflow {
         $wf,
         Workflow::History->new(
             {   workflow_id => $id,
-                action      => 'Create workflow',
-                description => 'Create new workflow',
-                user        => 'n/a',
+                action      => $persister->get_create_action($wf),
+                description => $persister->get_create_description($wf),
+                user        => $persister->get_create_user($wf),
                 state       => $wf->state,
                 date        => DateTime->now( time_zone => $wf->time_zone() ),
                 time_zone   => $wf->time_zone(),
@@ -405,19 +407,8 @@ sub associate_observers_with_workflow {
     $wf->add_observer($_) for ( @{$observers} );
 }
 
-sub _initialize_workflow_config {
-    my $self = shift;
-    my $wf_type = shift;
-    $log ||= get_logger();
-    if ( ref($self->config_callback) eq 'CODE' ) {
-        my $args = &{ $self->config_callback }( $wf_type );
-        $self->add_config_from_file( %$args ) if $args && %$args;
-    }
-}
-
 sub _get_workflow_config {
     my ( $self, $wf_type ) = @_;
-    $self->_initialize_workflow_config( $wf_type ) unless $self->{_workflow_config}{ $wf_type };
     return $self->{_workflow_config}{$wf_type};
 }
 
@@ -1012,44 +1003,6 @@ no sense to call new - and calling new will result in a L<Workflow::Exception>
 
 L</instance> should be called or the imported 'FACTORY' should be utilized.
 
-=head1 DYNAMIC CONFIG LOADING
-
-If you have either a large set of config files or a set of very large
-config files then you may not want to incur the overhead of loading
-each and every one on startup if you cannot predict which set you will
-use in that instance of your application.
-
-This approach doesn't make much sense in a persistent environment such
-as mod_perl but it may lower startup costs if you have regularly
-scheduled scripts that may not need to touch all possible types of
-workflow.
-
-To do this you can specify a callback that the factory will use to
-retrieve batched hashes of config declarations. Whenever an unknown
-workflow name is encountered the factory will first try to load your
-config declarations then continue.
-
-The callback takes one argument which is the workflow type. It should
-return a reference to a hash of arguments in a form suitable for
-C<add_config_from_file>.
-
-For example:
-
- use Workflow::Factory qw(FACTORY);
- use My::Config::System;
-
- sub init {
-   my $self = shift;
-
-   FACTORY->config_callback(
-     sub {
-       my $wf_type = shift;
-       my %ret = My::Config::System->get_files_for_wf( $wf_type ) || ();
-       return \%ret;
-     }
-   );
- }
-
 =head1 SUBCLASSING
 
 =head2 Implementation and Usage
